window.Gleam.initSearch([{"doc":"glue","title":"glue","content":"# glue\n\n[![Package Version](https://img.shields.io/hexpm/v/glue)](https://hex.pm/packages/glue)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glue/)\n\nA package for generating functions from your Gleam code!\n\n## Generators\n\n- [compare](#compare)\n- [list_variants](#list_variants)\n\n### compare\n\nGiven a module containing this type:\n\n```gleam\npub type LogLevel {\n  Debug\n  Info\n  Warn\n  Error\n}\n```\n\nThis generator will generate the following function:\n\n```gleam\npub fn compare_log_level(a: LogLevel, b: LogLevel) -&gt; Order {\n  let to_int = fn(x) {\n    case x {\n      Debug -&gt; 0\n      Info -&gt; 1\n      Warn -&gt; 2\n      Error -&gt; 3\n    }\n  }\n  int.compare(to_int(a), to_int(b))\n}\n```\n\n### list_variants\n\nGiven a module containing this type:\n\n```gleam\npub type Direction {\n  North\n  East\n  South\n  West\n}\n```\n\nThis generator will generate the following function:\n\n```gleam\npub fn direction_list() -&gt; List(Direction) {\n  [North, East, South, West]\n}\n```\n\n\n## Installation\n\nAdd the package to your Gleam project\n\n```sh\ngleam add glue\n```\n\nAPI documentation can be found at &lt;https://hexdocs.pm/glue&gt;.\n","url":"index.html"},{"doc":"glue","title":"Error","content":"pub type Error {\n  ParseError(glance.Error)\n  TypeNotFound(type_name: String)\n  TypeIsNotEnum(type_name: String, variant: String)\n}\n\nParseError(glance.Error)\n\n\nTypeNotFound(type_name: String)\n\n\nTypeIsNotEnum(type_name: String, variant: String)\n\n\nSynonyms:\nglue.Error\nglue Error","url":"glue.html#Error"},{"doc":"glue","title":"generate_compare","content":"pub fn generate_compare(\n  src: String,\n  type_name: String,\n) -&gt; Result(String, Error)\n Generate a function that lists all the variants of a given custom type.\n\n Errors if: \n - The source is invalid.\n - If type cannot be found.\n - If the type has variants that are records and as such cannot be listed\n   without being given arguments.\nSynonyms:\nglue.generate_compare\nglue generate_compare","url":"glue.html#generate_compare"},{"doc":"glue","title":"generate_list_variants","content":"pub fn generate_list_variants(\n  src: String,\n  type_name: String,\n) -&gt; Result(String, Error)\n Generate a function that lists all the variants of a given custom type.\n\n Errors if: \n - The source is invalid.\n - If type cannot be found.\n - If the type has variants that are records and as such cannot be listed\n   without being given arguments.\nSynonyms:\nglue.generate_list_variants\nglue generate_list_variants","url":"glue.html#generate_list_variants"},{"doc":"glue","title":"glue","content":"","url":"glue.html"}]);